==> tetzle_2.1.0.orig.tar.bz2: tetzle-2.1.0/translations/tetzle_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Bild auswählen</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Erscheinungsbild</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Abgeschrägte Kanten</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Schlagschatten</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Farben</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Hintergrund:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Schatten:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Hervorgehoben:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Bild nicht gefunden.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Bitte warten</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Bild wird geladen ...</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Puzzle wird erzeugt ...</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Teile werden erzeugt ...</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Puzzle wird geladen ...</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Unbekanntes Dateiformat</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Unbekanntes Element &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>Fehler beim Parsen der XML-Datei.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Teile werden geladen ...</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Teile werden geholt ...</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Teile werden gelegt ...</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Fertiggestellt</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Spiel auswählen</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Aktuelle Spiele</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Neues Spiel</translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Bildeigenschaften</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Name:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Tags:</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Anwendungssprache auswählen:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Systemeinstellung&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Hinweis</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Bitte starten Sie diese Anwendung neu um den Wechsel der Sprache auszuführen.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Bild hinzufügen</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Bild entfernen</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Bildeigenschaften</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 Teile</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Bilder werden kopiert ...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Remove selected image?</source>
        <translation>Ausgewähltes Bild entfernen?</translation>
    </message>
    <message>
        <source>Remove selected image?

There are saved games using this image that will also be removed.</source>
        <translation>Ausgewähltes Bild entfernen?

Es existieren gespeicherte Spiele, die dieses Bild benutzen und die ebenfalls gelöscht werden.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Unbenannt</translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Unbenannt</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 Teile %2 %3% fertiggestellt</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Spiel löschen</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Ausgewähltes Spiel löschen?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Übersicht</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Tag hinzufügen</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Tag löschen</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Nicht getaggt</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Alle Bilder</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Unbenannt %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Frage</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Ausgewähltes Tag löschen?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Ein Tag mit diesem Namen existiert bereits.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Spiel</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Teile holen</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Auswählen ...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Ansicht</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>Ver&amp;größern</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Ver&amp;kleinern</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>In Fenster &amp;einpassen</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>Ü&amp;bersicht zeigen</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>&amp;Vollbild</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;Erscheinungsbild ...</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;Sprache ...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Steuerung</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>Ü&amp;ber</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Über &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Steuerung</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Teile aufnehmen:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Linksklick oder Leertaste</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Teile ablegen:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Teile auswählen:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Ziehen mit linker Maustaste</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Teile drehen:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Rechtsklick, Strg + Linksklick, oder R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Puzzle verschieben:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Mittelklick, Umschalt + Linksklick, oder Pfeiltasten</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Puzzlegröße ändern:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Mausrad oder +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Zeiger bewegen:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Maus bewegen oder W, A, D, S</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>Über Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Ein Puzzlespiel mit Tetrominos als Puzzleteile</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Veröffentlicht unter der &lt;a href=%1&gt;GPL-3&lt;/a&gt;-Lizenz</translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>??%</source>
        <translation>??%</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Select OpenGL version.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>version</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> tetzle-2.2.3.tar.bz2: tetzle-2.2.3/translations/tetzle_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Bild auswählen</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Erscheinungsbild</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Abgeschrägte Kanten</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Schlagschatten</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Farben</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Hintergrund:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Schatten:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Hervorgehoben:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Bild nicht gefunden.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Bitte warten</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Bild wird geladen ...</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Puzzle wird erzeugt ...</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Teile werden erzeugt ...</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Puzzle wird geladen ...</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Unbekanntes Dateiformat</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Unbekanntes Element &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>Fehler beim Parsen der XML-Datei.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Teile werden geladen ...</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Teile werden geholt ...</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Teile werden gelegt ...</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Fertiggestellt</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Spiel auswählen</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Aktuelle Spiele</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Neues Spiel</translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Bildeigenschaften</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Name:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Tags:</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Anwendungssprache auswählen:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Systemeinstellung&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Hinweis</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Bitte starten Sie diese Anwendung neu um den Wechsel der Sprache auszuführen.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Bild hinzufügen</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Bild entfernen</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Bildeigenschaften</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 Teile</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Bilder werden kopiert ...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Remove selected image?</source>
        <translation>Ausgewähltes Bild entfernen?</translation>
    </message>
    <message>
        <source>Remove selected image?

There are saved games using this image that will also be removed.</source>
        <translation>Ausgewähltes Bild entfernen?

Es existieren gespeicherte Spiele, die dieses Bild benutzen und die ebenfalls gelöscht werden.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Unbenannt</translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Unbenannt</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 Teile %2 %3% fertiggestellt</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Spiel löschen</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Ausgewähltes Spiel löschen?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Übersicht</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Tag hinzufügen</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Tag löschen</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Nicht getaggt</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Alle Bilder</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Unbenannt %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Frage</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Ausgewähltes Tag löschen?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Ein Tag mit diesem Namen existiert bereits.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Spiel</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Teile holen</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Auswählen ...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Ansicht</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>Ver&amp;größern</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Ver&amp;kleinern</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>In Fenster &amp;einpassen</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>Ü&amp;bersicht zeigen</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>&amp;Vollbild</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;Erscheinungsbild ...</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;Sprache ...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Steuerung</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>Ü&amp;ber</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Über &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Steuerung</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Teile aufnehmen:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Linksklick oder Leertaste</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Teile ablegen:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Teile auswählen:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Ziehen mit linker Maustaste</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Teile drehen:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Rechtsklick, Strg + Linksklick, oder R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Puzzle verschieben:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Mittelklick, Umschalt + Linksklick, oder Pfeiltasten</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Puzzlegröße ändern:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Mausrad oder +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Zeiger bewegen:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Maus bewegen oder W, A, D, S</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>Über Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Ein Puzzlespiel mit Tetrominos als Puzzleteilen</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Veröffentlicht unter der &lt;a href=%1&gt;GPL-3&lt;/a&gt;-Lizenz</translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>??%</source>
        <translation>??%</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Select OpenGL version.</source>
        <translation>OpenGL-Version auswählen.</translation>
    </message>
    <message>
        <source>version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Images to add to the choose game dialog.</source>
        <translation>Bilder zum Hinzufügen zum Spiel-auswählen-Dialog.</translation>
    </message>
</context>
</TS>
